@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '0.36';
+$VERSION = '0.37';
 
 #----------------------------------------------------------------------------
 # Library Modules
@@ -33,7 +33,7 @@ sub new {
     # configure databases
     for my $db (qw(CPANSTATS LITESTATS LITEARTS)) {
         die "No configuration for $db database\n"   unless($cfg->SectionExists($db));
-        my %opts = map {$_ => $cfg->val($db,$_);} qw(driver database dbfile dbhost dbport dbuser dbpass);
+        my %opts = map {$_ => ($cfg->val($db,$_)||undef);} qw(driver database dbfile dbhost dbport dbuser dbpass);
         $opts{AutoCommit} = 0;
         $self->{$db} = CPAN::Testers::Common::DBUtils->new(%opts);
         die "Cannot configure $db database\n" unless($self->{$db});
@@ -269,6 +269,28 @@ sub insert_stats {
         $self->{$db}->do_query($INSERT,@fields);
     }
 
+    # push page requests
+    # - note we only update the author if this is the *latest* version of the distribution
+    my $author = $fields[1] eq 'cpan' ? $fields[3] : $self->_get_author($fields[4],$fields[5]);
+    $self->{CPANSTATS}->do_query("INSERT INTO page_requests (type,name,weight) VALUES ('author',?,1)",$author)  if($author);
+    $self->{CPANSTATS}->do_query("INSERT INTO page_requests (type,name,weight) VALUES ('distro',?,1)",$fields[4]);
+
+    if($fields[1] ne 'cpan') {
+        $self->{CPANSTATS}->do_query('INSERT INTO release_summary (dist,version,id,oncpan,distmat,perlmat,patched,pass,fail,na,unknown) VALUES (?,?,?,?,?,?,?,?,?,?,?)',
+            $fields[4],$fields[5],$fields[0],
+
+            $self->_oncpan($fields[4],$fields[5]) ? 1 : 2,
+
+            $fields[5] =~ /_/           ? 2 : 1,
+            $fields[7] =~ /^5.(7|9|11)/ ? 2 : 1,
+            $fields[7] =~ /patch/       ? 2 : 1,
+
+            $fields[1] eq 'pass'    ? 1 : 0,
+            $fields[1] eq 'fail'    ? 1 : 0,
+            $fields[1] eq 'na'      ? 1 : 0,
+            $fields[1] eq 'unknown' ? 1 : 0);
+    }
+
     if((++$self->{stat_count} % 50) == 0) {
         $self->{CPANSTATS}->do_commit;
         $self->{LITESTATS}->do_commit;
@@ -298,6 +320,12 @@ sub insert_article {
 #----------------------------------------------------------------------------
 # Private Functions
 
+sub _get_author {
+    my ($self,$dist,$version) = @_;
+    my @rows = $self->{CPANSTATS}->get_query('array','SELECT author FROM ixlatest WHERE dist=? AND version=? LIMIT 1',$dist,$version);
+    return @rows ? $rows[0]->[0] : '';
+}
+
 sub _valid_field {
     my ($self,$id,$name,$value) = @_;
     return 1    if(defined $value);
@@ -313,6 +341,17 @@ sub _get_lastid {
     return $rows[0]->[0] || 0;
 }
 
+sub _oncpan {
+    my ($self,$dist,$vers) = @_;
+
+    my @rows = $self->{CPANSTATS}->get_query('array','SELECT DISTINCT(type) FROM uploads WHERE dist=? AND version=?',$dist,$vers);
+    my $type = @rows ? $rows[0]->[0] : undef;
+
+    return 1    unless($type);          # assume it's a new release
+    return 0    if($type eq 'backpan'); # on backpan only
+    return 1;                           # on cpan or new upload
+}
+
 sub _log {
     my $self = shift;
     my $log = $self->{logfile} or return;
